ScopedContainer

Struct ScopedContainer 

pub struct ScopedContainer { /* private fields */ }
A container with an associated scope identifier.

Useful for request-scoped or session-scoped services where you need to track the scope identity.

Examples

use dependency_injector::{Container, ScopedContainer};

#[derive(Clone)]
struct RequestContext {
    request_id: String,
}

let root = Container::new();

// Create a request-scoped container
let request = ScopedContainer::from_parent(&root);
request.singleton(RequestContext {
    request_id: "req-123".to_string(),
});

let ctx = request.get::<RequestContext>().unwrap();
assert_eq!(ctx.request_id, "req-123");

Implementations

Source

impl ScopedContainer

pub fn new() -> Self

Create a new scoped container with no parent.

pub fn from_parent(parent: &Container) -> Self

Create a scoped container from a parent container.

pub fn from_scope(parent: &ScopedContainer) -> Self

Create a scoped container from another scoped container.

pub fn scope(&self) -> Scope

Get the scope identifier.

pub fn singleton<T: Injectable>(&self, instance: T)

Register a singleton in this scope.

pub fn lazy<T: Injectable, F>(&self, factory: F)
where F: Fn() -> T + Send + Sync + 'static,

Register a lazy singleton in this scope.

pub fn transient<T: Injectable, F>(&self, factory: F)
where F: Fn() -> T + Send + Sync + 'static,

Register a transient service in this scope.

pub fn register<T: Injectable>(&self, instance: T)

Alias for singleton - register an instance.

pub fn register_factory<T: Injectable, F>(&self, factory: F)
where F: Fn() -> T + Send + Sync + 'static,

Register using a factory.

pub fn get<T: Injectable>(&self) -> Result<Arc<T>>

Resolve a service from this scope or parent scopes.

pub fn resolve<T: Injectable>(&self) -> Result<Arc<T>>

Alias for get.

pub fn try_get<T: Injectable>(&self) -> Option<Arc<T>>

Try to resolve a service, returning None if not found.

pub fn try_resolve<T: Injectable>(&self) -> Option<Arc<T>>

Alias for try_get.

pub fn contains<T: Injectable>(&self) -> bool

Check if a service exists in this scope or parent scopes.

pub fn has<T: Injectable>(&self) -> bool

Alias for contains.

pub fn container(&self) -> &Container

Get the underlying container.

pub fn container_mut(&mut self) -> &mut Container

Get the underlying container mutably.

pub fn depth(&self) -> u32

Get the scope depth.